A list containing matrices Y = x[-(1:p), ], X which contains lags 1 - p of x combined column-wise,
A which is the \(np \times n\) transition matrix, where n is the number of series in x, and the VAR residual matrix res = Y - X %*% A.
A list with the following elements:
Y
x[-(1:p), ].
X
lags 1 - p of x combined column-wise.
A
\(np \times n\) transition matrix, where n is the number of series in x.
res
VAR residual matrix: Y - X %*% A.